unit uLaitos;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, Mask, ExtCtrls;

type
  TfLeitos = class(TForm)
    GroupBox1: TGroupBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    edtLeito: TEdit;
    edtCodLeito: TEdit;
    edtQuarto: TEdit;
    btnSalvar: TBitBtn;
    btnSair: TBitBtn;
    btnNovo: TBitBtn;
    btnAlterar: TBitBtn;
    btnDeletar: TBitBtn;
    Panel1: TPanel;
    Image1: TImage;
    Label6: TLabel;
    Label7: TLabel;
    edtAndar: TEdit;
    cbSetor: TComboBox;
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormCreate(Sender: TObject);
    procedure btnNovoClick(Sender: TObject);
    procedure btnSairClick(Sender: TObject);
    procedure btnSalvarClick(Sender: TObject);
    procedure btnAlterarClick(Sender: TObject);
    procedure btnDeletarClick(Sender: TObject);
  private
    { Private declarations }

  public
    { Public declarations }
      procedure desabilitarComponentes;
      procedure habilitaDesabilitaBotao(novo, alterar, deletar, salvar: boolean);
      procedure habilitarComponentes;
      procedure gravarRegistro;
      procedure consulta(where: string);
      procedure deletaRegistro;
    
  end;

var
  fLeitos: TfLeitos;

implementation

uses uDm, uLookupSemBde;

{$R *.dfm}

procedure TfLeitos.FormClose(Sender: TObject; var Action: TCloseAction);
begin
   Action:= cafree;
   fLeitos:= nil;
end;


procedure TfLeitos.habilitarComponentes;
var
   i: integer;
begin

   for i:= 0 to  ComponentCount -1 do
   begin
      if Components[i] is tEdit then
      begin
         (Components[i] as tEdit).Enabled:= true;
         (Components[i] as tEdit).Color:= clWindow;
      end
      else if Components[i] is TComboBox then
      begin
         (Components[i] as TComboBox).Enabled:= true;
         (Components[i] as TComboBox).Color:= clWindow;
      end;
   end;
   edtCodLeito.Color:= $007a513d;
   edtCodLeito.Font.Color:= clWhite;
end;

procedure TfLeitos.desabilitarComponentes;
var
   i: integer;
begin

   for i:= 0 to  ComponentCount -1 do
   begin
      if Components[i] is tEdit then
      begin
         (Components[i] as tEdit).Enabled:= false;
         (Components[i] as tEdit).clear;
         (Components[i] as tEdit).Color:= clMedGray;
      end
      else if Components[i] is TComboBox then
      begin
         (Components[i] as TComboBox).Enabled:= false;
         (Components[i] as TComboBox).ItemIndex:= -1;         
         (Components[i] as TComboBox).Color:= clMedGray;
      end;
   end;   
end;

procedure TfLeitos.FormCreate(Sender: TObject);
begin
   desabilitarComponentes;
   habilitaDesabilitaBotao(true, false, false, false);   
end;

procedure TfLeitos.btnNovoClick(Sender: TObject);
begin
   habilitarComponentes;
   habilitaDesabilitaBotao(false, false, false, true);

   consulta('');

   edtCodLeito.Text:= dm.getGenerator('gen_leito');
   dm.cds1.Insert;
   edtLeito.SetFocus;

end;

procedure TfLeitos.btnSairClick(Sender: TObject);
begin
   close;
end;

procedure TfLeitos.habilitaDesabilitaBotao(novo, alterar, deletar, salvar: boolean);
begin
   btnNovo.enabled:= Novo;
   btnDeletar.enabled:= deletar;
   btnAlterar.enabled:= alterar;
   btnSalvar.enabled:= salvar;
end;


procedure TfLeitos.btnSalvarClick(Sender: TObject);
begin

   if (edtLeito.Text = '') or
         (edtQuarto.Text = '') or
         (edtAndar.Text = '') or
         (cbSetor.Text = '') then
   begin
      messageDlg('Todos os campos so obrigatrios, preencha-os antes de prosseguir', mtInformation, [mbOk], 0);
      abort;
   end;


   try
      gravarRegistro;
      messageDlg('Registro salvo com sucesso', mtInformation, [mbOk], 0);
      except on e:exception do
         messageDlg(e.message, mtError, [mbOk], 0);
   end;

   habilitaDesabilitaBotao(true, false, false, false);
   desabilitarComponentes;
end;


procedure TfLeitos.gravarRegistro;
begin
   if not dm.cds1.Active then
      raise Exception.Create('Execute uma consulta antes');

   try
      with dm.cds1 do
      begin
         Edit;
         FieldByName('id_leito').AsInteger:= strToInt(edtCodLeito.Text);
         FieldByName('setor').asString:= cbSetor.Text;
         FieldByName('leito').asString:= edtLeito.Text;
         FieldByName('andar').asString:= edtAndar.Text;
         FieldByName('quarto').asString:= edtQuarto.Text;
         Post;
         ApplyUpdates(-1);
      end;
      except on  e: exception do
         messageDlg('No foi possvel salvar registro' + e.Message, mtError, [mbOk], 0);
   end;
end;


procedure TfLeitos.consulta(where: string);
begin

   try
      dm.cds1.Close;
      dm.sql1.CommandText:= 'select * from leito ' + where;
      dm.cds1.Open;
      except on  e: exception do
         messageDlg('No foi possvel executar a consulta: ' + e.Message, mtError, [mbOk], 0);
   end;
end;

procedure TfLeitos.deletaRegistro;
begin

   try
      consulta(' where id_leito = ' + edtCodLeito.Text);
      dm.cds1.Delete;
      dm.cds1.ApplyUpdates(-1);
      desabilitarComponentes;

      messageDlg('Registro deletado com sucesso', mtInformation, [mbOk], 0);

      except on  e: exception do
         messageDlg('No foi possvel executar a consulta: ' + e.Message, mtError, [mbOk], 0);
   end;
end;

procedure TfLeitos.btnAlterarClick(Sender: TObject);
begin
   consulta(' where id_leito = ' + edtCodLeito.Text);
   gravarRegistro;
end;

procedure TfLeitos.btnDeletarClick(Sender: TObject);
begin
   deletaRegistro;
end;

end.
